﻿using Hotline.FlowEngine.Notifies;
using Hotline.FlowEngine.Workflows;
using Hotline.Orders;
using Hotline.Settings;
using Hotline.Share.Dtos.FlowEngine;
using Hotline.Share.Enums.Order;
using MediatR;
using XF.Domain.Entities;
using XF.Domain.Exceptions;

namespace Hotline.Application.Handlers.FlowEngine;

public class NextStepHandler : INotificationHandler<NextStepNotify>
{
    private readonly IOrderDomainService _orderDomainService;

    public NextStepHandler(IOrderDomainService orderDomainService)
    {
        _orderDomainService = orderDomainService;
    }

    /// <summary>Handles a notification</summary>
    /// <param name="notification">The notification</param>
    /// <param name="cancellationToken">Cancellation token</param>
    public async Task Handle(NextStepNotify notification, CancellationToken cancellationToken)
    {
        var workflow = notification.Workflow;
        var data = notification.Dto;
        switch (workflow.ModuleCode)
        {
            case WorkflowModuleConsts.OrderManage:
                await _orderDomainService.OrderManageAsync(EOrderStatus.WaitForSign, 
                    notification.FlowAssignType, notification.IsCountersignEnd, notification.IsCountersignStart,
                    workflow.ExternalId, workflow.CurrentStepTime, workflow.CurrentStepName, 
                    data.Handlers.Select(d => d.Id), cancellationToken);
                break;
        }
    }
}